"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const digitReducer = ({ value, result, posValue }) => {
    const q = Math.floor(value / posValue);
    return {
        value: value - q * posValue,
        posValue: posValue / 20,
        result: [...result, utils_1.valueToDigit(q)]
    };
};
const encodeAxis = (length, value) => utils_1.arrayOf(length, null).reduce(digitReducer, { value, posValue: 20, result: [] }).result;
const interleave = (length) => (xs, ys) => {
    const zipped = utils_1.zip(xs, ys);
    const padding = length > 8 ? [] : utils_1.arrayOf(8 - length, '0');
    const digits = [...utils_1.flatten(zipped), ...padding];
    return [...digits.slice(0, 8), '+', ...digits.slice(8)].join('');
};
const normalizeLatitude = (lat) => Math.min(180, Math.max(0, lat + 90));
const normalizeLongitude = (lon) => (lon + 180) % 360;
const encode = (coordinates, length = 10) => {
    if (length < 2 || length > 10 || length % 2 !== 0)
        return null;
    if (!utils_1.isValidCoordinates(coordinates))
        return null;
    const latitude = normalizeLatitude(utils_1.parseNum(coordinates.latitude));
    const longitude = normalizeLongitude(utils_1.parseNum(coordinates.longitude));
    return interleave(length)(encodeAxis(length / 2, latitude), encodeAxis(length / 2, longitude));
};
exports.default = encode;
//# sourceMappingURL=encode.js.map