"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const encode_1 = __importDefault(require("./encode"));
const decode_1 = __importDefault(require("./decode"));
const utils_1 = require("./utils");
const adjust = (axis, refAxis, resolution) => {
    const refFloat = utils_1.parseNum(refAxis);
    if (axis > refFloat + resolution / 2)
        return axis - resolution;
    if (axis < refFloat - resolution / 2)
        return axis + resolution;
    return axis;
};
const expand = (shortCode, ref) => {
    if (!utils_1.isValidCode(shortCode))
        return null;
    if (!utils_1.isValidCoordinates(ref))
        return null;
    const prefixLength = 11 - shortCode.length;
    if (prefixLength === 0)
        return shortCode;
    const prefixedCode = encode_1.default(ref, prefixLength);
    if (!prefixedCode)
        return null;
    const code = `${prefixedCode.slice(0, prefixLength)}${shortCode}`;
    const coords = decode_1.default(code);
    if (!coords)
        return null;
    const { latitude, longitude } = coords;
    const resolution = Math.pow(20, 2 - prefixLength / 2);
    return encode_1.default({
        latitude: adjust(latitude, ref.latitude, resolution),
        longitude: adjust(longitude, ref.longitude, resolution)
    });
};
exports.default = expand;
//# sourceMappingURL=expand.js.map